@@ -2,13 +2,13 @@ package LCFG::Build::Utils::OSXPkg;    # -*-cperl-*-
 use strict;
 use warnings;
 
-# $Id: OSXPkg.pm.in 26631 2014-10-31 10:52:42Z squinney@INF.ED.AC.UK $
+# $Id: OSXPkg.pm.in 27861 2015-06-24 10:10:43Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Tools/lib/LCFG/Build/Utils/MacOSX.pm.in,v $
-# $Revision: 26631 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_4_5/lib/LCFG/Build/Utils/OSXPkg.pm.in $
-# $Date: 2014-10-31 10:52:42 +0000 (Fri, 31 Oct 2014) $
+# $Revision: 27861 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Tools/LCFG_Build_Tools_0_5_0/lib/LCFG/Build/Utils/OSXPkg.pm.in $
+# $Date: 2015-06-24 11:10:43 +0100 (Wed, 24 Jun 2015) $
 
-our $VERSION = '0.4.5';
+our $VERSION = '0.5.0';
 
 use File::Copy ();
 use File::Spec ();
@@ -77,7 +77,7 @@ sub build {
 
   # pkgbuild by default filters .DS_Store, CVS and .svn, but doesn't
   # if we use the --filter option, so add these explicitly
-  my @default_filters = ( qw/ .DS_Store CVS .svn / );
+  my @default_filters = ( qw/ \.DS_Store CVS \.svn / );
 
   # Add a command line option for each filter
   foreach my $filter ( @default_filters, @$filters ) {
@@ -116,7 +116,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Utils::OSXPkg version 0.4.5
+    This documentation refers to LCFG::Build::Utils::OSXPkg version 0.5.0
 
 =head1 DESCRIPTION
 
